@@ -36,11 +36,8 @@ from django_filters.rest_framework import DjangoFilterBackend
 from drf_yasg.inspectors import CoreAPICompatInspector, NotHandled
 from collections import defaultdict
 
-from base64 import b64encode
 from datetime import datetime
-from appdirs import user_cache_dir
 from functools import wraps
-from requests.auth import HTTPBasicAuth
 from pkg_resources import parse_version
 from colorama import Fore
 from boxing import boxing
@@ -56,9 +53,7 @@ from core.utils.exceptions import LabelStudioDatabaseLockedException
 
 
 # these functions will be included to another modules, don't remove them
-from core.utils.params import (
-    get_bool_env, bool_from_request, float_from_request, int_from_request
-)
+from core.utils.params import int_from_request
 
 logger = logging.getLogger(__name__)
 url_validator = URLValidator()
@@ -351,7 +346,11 @@ def retry_database_locked():
 
 
 def get_app_version():
-    return pkg_resources.get_distribution('label-studio').version
+    version = pkg_resources.get_distribution('label-studio').version
+    if isinstance(version, str):
+        return version
+    elif isinstance(version, dict):
+        return version.get('version') or version.get('latest_version')
 
 
 def get_latest_version():
@@ -414,7 +413,9 @@ def check_for_the_latest_version(print_message):
 
 
 # check version ASAP while package loading
-check_for_the_latest_version(print_message=True)
+# skip notification for uwsgi, as we're running in production ready mode
+if settings.APP_WEBSERVER != 'uwsgi':
+    check_for_the_latest_version(print_message=True)
 
 
 def collect_versions(force=False):
