@@ -15,7 +15,7 @@ from rest_framework.response import Response
 from rest_framework.views import APIView
 
 from core.permissions import all_permissions
-from core.utils.common import get_object_with_check_and_log, bool_from_request, batch
+from core.utils.common import get_object_with_check_and_log, batch
 from projects.models import Project
 from tasks.models import Task
 from .models import DataExport, Export
