@@ -7,6 +7,7 @@ import ssl
 import uuid
 import pickle
 import logging
+import mimetypes
 try:
     import ujson as json
 except:
@@ -19,6 +20,8 @@ from django.core.files.uploadedfile import SimpleUploadedFile
 from urllib.request import urlopen
 
 from .models import FileUpload
+from core.utils.io import url_is_local
+from core.utils.exceptions import ImportFromLocalIPError
 
 logger = logging.getLogger(__name__)
 csv.field_size_limit(131072 * 10)
@@ -58,10 +61,48 @@ def check_file_sizes_and_number(files):
 
 def create_file_upload(request, project, file):
     instance = FileUpload(user=request.user, project=project, file=file)
+    if settings.SVG_SECURITY_CLEANUP:
+        content_type, encoding = mimetypes.guess_type(str(instance.file.name))
+        if content_type in ['image/svg+xml']:
+            clean_xml = allowlist_svg(instance.file.read())
+            instance.file.seek(0)
+            instance.file.write(clean_xml)
+            instance.file.truncate()
     instance.save()
     return instance
 
 
+def allowlist_svg(dirty_xml):
+    """Filter out malicious/harmful content from SVG files
+    by defining allowed tags
+    """
+    from lxml.html import clean
+
+    allow_tags = [
+            'xml',
+            'svg',
+            'circle',
+            'ellipse',
+            'line',
+            'path',
+            'polygon',
+            'polyline',
+            'rect'
+    ]
+
+    cleaner = clean.Cleaner(
+            allow_tags=allow_tags,
+            style=True,
+            links=True,
+            add_nofollow=False,
+            page_structure=True,
+            safe_attrs_only=False,
+            remove_unknown_tags=False)
+
+    clean_xml = cleaner.clean_html(dirty_xml)
+    return clean_xml
+
+
 def str_to_json(data):
     try:
         json_acceptable_string = data.replace("'", "\"")
@@ -131,6 +172,12 @@ def load_tasks(request, project):
             
         # download file using url and read tasks from it
         else:
+            if settings.SSRF_PROTECTION_ENABLED and url_is_local(url):
+                raise ImportFromLocalIPError
+
+            if url.strip().startswith('file://'):
+                raise ValidationError('"url" is not valid')
+
             data_keys, found_formats, tasks, file_upload_ids = tasks_from_url(
                 file_upload_ids, project, request, url
             )
