@@ -1,5 +1,6 @@
 """This file and its contents are licensed under the Apache License 2.0. Please see the included NOTICE for copyright information and LICENSE for a copy of the license.
 """
+import random
 import logging
 import ujson as json
 
@@ -153,6 +154,12 @@ def rename_labels(project, queryset, **kwargs):
             annotation.save(update_fields=['result'])
             annotation_count += 1
 
+    # update summaries
+    project.summary.reset()
+    project.summary.update_data_columns(project.tasks.all())
+    annotations = Annotation.objects.filter(task__project=project)
+    project.summary.update_created_annotations_and_labels(annotations)
+
     return {'response_code': 200, 'detail': f'Updated {label_count} labels in {annotation_count}'}
 
 
@@ -189,7 +196,157 @@ def rename_labels_form(user, project):
     }]
 
 
+def add_data_field(project, queryset, **kwargs):
+    from django.db.models import F, Func, Value, JSONField
+
+    request = kwargs['request']
+    value_name = request.data.get('value_name')
+    value_type = request.data.get('value_type')
+    value = request.data.get('value')
+    size = queryset.count()
+
+    cast = {'String': str, 'Number': float, 'Expression': str}
+    assert value_type in cast.keys()
+    value = cast[value_type](value)
+
+    if value_type == 'Expression':
+        add_expression(queryset, size, value, value_name)
+
+    else:
+
+        # sqlite
+        if settings.DJANGO_DB == settings.DJANGO_DB_SQLITE:
+            tasks = list(queryset.only('data'))
+            for task in tasks:
+                task.data[value_name] = value
+            Task.objects.bulk_update(tasks, fields=['data'], batch_size=1000)
+
+        # postgres and other DB
+        else:
+            queryset.update(
+                data=Func(
+                    F("data"),
+                    Value([value_name]),
+                    Value(value, JSONField()),
+                    function="jsonb_set",
+                )
+            )
+
+    project.summary.update_data_columns([queryset.first()])
+    return {'response_code': 200, 'detail': f'Updated {size} tasks'}
+
+
+def process_arrays(params):
+    start, end = params.find('['), -1
+    while start != end:
+        end = start + params[start:].find(']') + 1
+        params = params[0:start] + params[start:end].replace(',', ';') + params[end:]
+        start = end + params[end:].find('[') + 1
+    return params
+
+
+add_data_field_examples = (
+    'sample() or '
+    'random(<min_int>, <max_int>) or '
+    'choices(["<value1>", "<value2>", ...], [<weight1>, <weight2>, ...]) or '
+    'replace("old-string", "new-string")'
+)
+
+
+def add_expression(queryset, size, value, value_name):
+    # simple parsing
+    command, args = value.split('(')
+    args = process_arrays(args)
+    args = args.replace(')', '').split(',')
+    args = [] if len(args) == 1 and args[0] == '' else args
+    # return comma back, convert quotation mark to doubled quotation mark for json parsing
+    for i, arg in enumerate(args):
+        args[i] = arg.replace(';', ',').replace("'", '"')
+
+    tasks = list(queryset.only('data'))
+
+    # permutation sampling
+    if command == 'sample':
+        assert len(args) == 0, "sample() doesn't have arguments"
+        values = random.sample(range(0, size), size)
+        for i, v in enumerate(values):
+            tasks[i].data[value_name] = v
+
+    # uniform random
+    elif command == 'random':
+        assert len(args) == 2, 'random() should have 2 args: min & max'
+        minimum, maximum = int(args[0]), int(args[1])
+        for i in range(size):
+            tasks[i].data[value_name] = random.randint(minimum, maximum)
+
+    # sampling with choices and weights
+    elif command == 'choices':
+        assert 0 < len(args) < 3, 'choices() should have 1 or 2 args: values & weights (default=None)'
+        weights = json.loads(args[1]) if len(args) == 2 else None
+        values = random.choices(
+            population=json.loads(args[0]),
+            weights=weights,
+            k=size
+        )
+        for i, v in enumerate(values):
+            tasks[i].data[value_name] = v
+
+    # replace
+    elif command == 'replace':
+        assert len(args) == 2, 'replace() should have 2 args: old value & new value'
+        old_value, new_value = json.loads(args[0]), json.loads(args[1])
+        for task in tasks:
+            if value_name in task.data:
+                task.data[value_name] = task.data[value_name].replace(old_value, new_value)
+
+    else:
+        raise Exception(
+            'Undefined expression, you can use: ' + add_data_field_examples
+        )
+
+    Task.objects.bulk_update(tasks, fields=['data'], batch_size=1000)
+
+
+def add_data_field_form(user, project):
+    return [{
+        'columnCount': 1,
+        'fields': [
+            {
+                'type': 'input',
+                'name': 'value_name',
+                'label': 'Name'
+            },
+            {
+                'type': 'select',
+                'name': 'value_type',
+                'label': 'Type',
+                'options': ['String', 'Number', 'Expression'],
+            },
+            {
+                'type': 'input',
+                'name': 'value',
+                'label': 'Value'
+            }
+        ]
+    }]
+
+
 actions = [
+    {
+        'entry_point': add_data_field,
+        'permission': all_permissions.tasks_change,
+        'title': 'Add Or Modify Data Field',
+        'order': 1,
+        'experimental': True,
+        'dialog': {
+            'text': 'Confirm that you want to add a new field in tasks. '
+                    'After this operation you must refresh the Data Manager page fully to see the new column! '
+                    'You can use the following expressions: ' + add_data_field_examples,
+            'type': 'confirm',
+            'form': add_data_field_form,
+        }
+    },
+
     {
         'entry_point': propagate_annotations,
         'permission': all_permissions.tasks_change,
