@@ -6,7 +6,7 @@ import sys
 
 if __name__ == '__main__':
     os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'core.settings.label_studio')
-    os.environ.setdefault('DEBUG', 'True')
+    # os.environ.setdefault('DEBUG', 'True')
     try:
         from django.core.management import execute_from_command_line
         from django.core.management.commands.runserver import Command as runserver
