@@ -13,30 +13,13 @@ logger = logging.getLogger(__name__)
 
 
 def _get_random_unlocked(task_query, user, upper_limit=None):
-    # get random task from task query, ignoring locked tasks
-    n = task_query.count()
-    if n > 0:
-        upper_limit = upper_limit or n
-        random_indices = np.random.permutation(upper_limit)
-        task_query_only = task_query.only('overlap', 'id')
-
-        for i in random_indices:
-            try:
-                task = task_query_only[int(i)]
-            except IndexError as exc:
-                logger.error(
-                    f'Task query out of range for {int(i)}, count={task_query_only.count()}. ' f'Reason: {exc}',
-                    exc_info=True,
-                )
-            except Exception as exc:
-                logger.error(exc, exc_info=True)
-            else:
-                try:
-                    task = Task.objects.select_for_update(skip_locked=True).get(pk=task.id)
-                    if not task.has_lock(user):
-                        return task
-                except Task.DoesNotExist:
-                    logger.debug('Task with id {} locked'.format(task.id))
+    for task in task_query.order_by('?').only('id')[:settings.RANDOM_NEXT_TASK_SAMPLE_SIZE]:
+        try:
+            task = Task.objects.select_for_update(skip_locked=True).get(pk=task.id)
+            if not task.has_lock(user):
+                return task
+        except Task.DoesNotExist:
+            logger.debug('Task with id {} locked'.format(task.id))
 
 
 def _get_first_unlocked(tasks_query, user):
@@ -142,14 +125,14 @@ def _try_uncertainty_sampling(tasks, project, user_solved_tasks_array, user, pre
 
 def get_not_solved_tasks_qs(user, project, prepared_tasks, assigned_flag, queue_info):
     user_solved_tasks_array = user.annotations.filter(task__project=project, task__isnull=False)
-
-    if project.skip_queue == project.SkipQueue.REQUEUE_FOR_ME:
-        user_solved_tasks_array = user_solved_tasks_array.filter(was_cancelled=False)
-        queue_info += ' Requeued for me from skipped tasks '
-
     user_solved_tasks_array = user_solved_tasks_array.distinct().values_list('task__pk', flat=True)
     not_solved_tasks = prepared_tasks.exclude(pk__in=user_solved_tasks_array)
 
+    if user.drafts.filter(was_postponed=True).exists():
+        user_postponed_drafts = user.drafts.filter(was_postponed=True).distinct()
+        user_postponed_tasks = user_postponed_drafts.values_list('task__pk', flat=True)
+        not_solved_tasks = not_solved_tasks.exclude(pk__in=user_postponed_tasks)
+
     # if annotator is assigned for tasks, he must to solve it regardless of is_labeled=True
     if not assigned_flag:
         not_solved_tasks = not_solved_tasks.filter(is_labeled=False)
@@ -161,13 +144,6 @@ def get_not_solved_tasks_qs(user, project, prepared_tasks, assigned_flag, queue_
         _, not_solved_tasks = _try_tasks_with_overlap(not_solved_tasks)
         queue_info += 'Show overlap first'
 
-    if project.skip_queue == project.SkipQueue.REQUEUE_FOR_ME:
-        # Ordering works different for sqlite and postgresql, details: https://code.djangoproject.com/ticket/19726
-        if settings.DJANGO_DB == settings.DJANGO_DB_SQLITE:
-            not_solved_tasks = not_solved_tasks.order_by('annotations__was_cancelled', 'updated_at')
-        else:
-            not_solved_tasks = not_solved_tasks.order_by('-annotations__was_cancelled', 'updated_at')
-
     return not_solved_tasks, user_solved_tasks_array, queue_info
 
 
@@ -206,6 +182,17 @@ def get_next_task_without_dm_queue(user, project, not_solved_tasks, assigned_fla
     return next_task, use_task_lock, queue_info
 
 
+def skipped_queue(next_task, prepared_tasks, project, user):
+    if not next_task and project.skip_queue == project.SkipQueue.REQUEUE_FOR_ME:
+        q = Q(task__project=project, task__isnull=False, was_cancelled=True)
+        skipped_tasks = user.annotations.filter(q).order_by('updated_at').values_list('task__pk', flat=True)
+        if skipped_tasks.exists():
+            preserved_order = Case(*[When(pk=pk, then=pos) for pos, pk in enumerate(skipped_tasks)])
+            next_task = prepared_tasks.filter(pk__in=skipped_tasks).order_by(preserved_order).first()
+
+    return next_task
+
+
 def get_next_task(user, prepared_tasks, project, dm_queue, assigned_flag=None):
     logger.debug(f'get_next_task called. user: {user}, project: {project}, dm_queue: {dm_queue}')
 
@@ -250,6 +237,9 @@ def get_next_task(user, prepared_tasks, project, dm_queue, assigned_flag=None):
             # set lock for the task with TTL 3x time more then current average lead time (or 1 hour by default)
             next_task.set_lock(user)
 
+        next_task = skipped_queue(next_task, prepared_tasks, project, user)
+
         logger.debug(f'get_next_task finished. next_task: {next_task}, queue_info: {queue_info}')
         return next_task, queue_info
 
+
