@@ -10,9 +10,9 @@ from django.db.models import JSONField
 from django.core.validators import MinLengthValidator, MaxLengthValidator
 from django.db import transaction, models
 from annoying.fields import AutoOneToOneField
-from functools import lru_cache
 
 from core.redis import start_job_async_or_sync
+from data_manager.managers import TaskQuerySet
 from tasks.models import Task, Prediction, Annotation, Q_task_finished_annotations, bulk_update_stats_project_tasks
 from core.utils.common import create_hash, get_attr_or_item, load_func
 from core.utils.exceptions import LabelStudioValidationErrorSentryIgnored
@@ -24,10 +24,16 @@ from core.label_config import (
     get_sample_task,
     get_all_labels,
     get_all_control_tag_tuples,
-    get_annotation_tuple,
+    get_annotation_tuple, check_control_in_config_by_regex, check_toname_in_config_by_regex,
+    get_original_fromname_by_regex, get_all_types,
 )
 from core.bulk_update_utils import bulk_update
 from label_studio_tools.core.label_config import parse_config
+from projects.functions import (
+    annotate_task_number, annotate_finished_task_number, annotate_total_predictions_number,
+    annotate_total_annotations_number, annotate_num_tasks_with_annotations,
+    annotate_useful_annotation_number, annotate_ground_truth_number, annotate_skipped_annotations_number
+)
 from labels_manager.models import Label
 
 
@@ -49,40 +55,30 @@ class ProjectManager(models.Manager):
         'skipped_annotations_number',
     ]
 
-    def with_counts(self):
-        return self.with_counts_annotate(self)
+    def with_counts(self, fields=None):
+        return self.with_counts_annotate(self, fields=fields)
 
     @staticmethod
-    def with_counts_annotate(queryset):
-        return queryset.annotate(
-            task_number=Count('tasks', distinct=True),
-            finished_task_number=Count('tasks', distinct=True, filter=Q(tasks__is_labeled=True)),
-            total_predictions_number=Count('tasks__predictions', distinct=True),
-            total_annotations_number=Count(
-                'tasks__annotations__id', distinct=True, filter=Q(tasks__annotations__was_cancelled=False)
-            ),
-            num_tasks_with_annotations=Count(
-                'tasks__id',
-                distinct=True,
-                filter=Q(tasks__annotations__isnull=False)
-                & Q(tasks__annotations__ground_truth=False)
-                & Q(tasks__annotations__was_cancelled=False)
-                & Q(tasks__annotations__result__isnull=False),
-            ),
-            useful_annotation_number=Count(
-                'tasks__annotations__id',
-                distinct=True,
-                filter=Q(tasks__annotations__was_cancelled=False)
-                & Q(tasks__annotations__ground_truth=False)
-                & Q(tasks__annotations__result__isnull=False),
-            ),
-            ground_truth_number=Count(
-                'tasks__annotations__id', distinct=True, filter=Q(tasks__annotations__ground_truth=True)
-            ),
-            skipped_annotations_number=Count(
-                'tasks__annotations__id', distinct=True, filter=Q(tasks__annotations__was_cancelled=True)
-            ),
-        )
+    def with_counts_annotate(queryset, fields=None):
+        available_fields = {
+            'task_number': annotate_task_number,
+            'finished_task_number': annotate_finished_task_number,
+            'total_predictions_number': annotate_total_predictions_number,
+            'total_annotations_number': annotate_total_annotations_number,
+            'num_tasks_with_annotations': annotate_num_tasks_with_annotations,
+            'useful_annotation_number': annotate_useful_annotation_number,
+            'ground_truth_number': annotate_ground_truth_number,
+            'skipped_annotations_number': annotate_skipped_annotations_number,
+        }
+        if fields is None:
+            to_annotate = available_fields
+        else:
+            to_annotate = {field: available_fields[field] for field in fields if field in available_fields}
+
+        for _, annotate_func in to_annotate.items():
+            queryset = annotate_func(queryset)
+
+        return queryset
 
 
 ProjectMixin = load_func(settings.PROJECT_MIXIN)
@@ -219,7 +215,8 @@ class Project(ProjectMixin, models.Model):
     )
 
     sampling = models.CharField(max_length=100, choices=SAMPLING_CHOICES, null=True, default=SEQUENCE)
-    skip_queue = models.CharField(max_length=100, choices=SkipQueue.choices, null=True, default=SkipQueue.REQUEUE_FOR_OTHERS)
+    skip_queue = models.CharField(max_length=100, choices=SkipQueue.choices, null=True,
+                                  default=SkipQueue.REQUEUE_FOR_OTHERS)
     show_ground_truth_first = models.BooleanField(_('show ground truth first'), default=False)
     show_overlap_first = models.BooleanField(_('show overlap first'), default=False)
     overlap_cohort_percentage = models.IntegerField(_('overlap_cohort_percentage'), default=100)
@@ -231,6 +228,8 @@ class Project(ProjectMixin, models.Model):
         _('task_data_password'), max_length=256, blank=True, null=True, help_text='Task data credentials: password'
     )
 
+    pinned_at = models.DateTimeField(_('pinned at'), null=True, default=None, help_text='Pinned date and time')
+
     def __init__(self, *args, **kwargs):
         super(Project, self).__init__(*args, **kwargs)
         self.__original_label_config = self.label_config
@@ -354,11 +353,13 @@ class Project(ProjectMixin, models.Model):
         self, maximum_annotations_changed, overlap_cohort_percentage_changed, tasks_number_changed
     ):
         # if only maximum annotations parameter is tweaked
-        if maximum_annotations_changed and not overlap_cohort_percentage_changed:
+        if maximum_annotations_changed and (not overlap_cohort_percentage_changed or self.maximum_annotations == 1):
             tasks_with_overlap = self.tasks.filter(overlap__gt=1)
             if tasks_with_overlap.exists():
                 # if there is a part with overlaped tasks, affect only them
                 tasks_with_overlap.update(overlap=self.maximum_annotations)
+            elif self.overlap_cohort_percentage < 100:
+                self._rearrange_overlap_cohort()
             else:
                 # otherwise affect all tasks
                 self.tasks.update(overlap=self.maximum_annotations)
@@ -489,14 +490,16 @@ class Project(ProjectMixin, models.Model):
         if not fields_from_config:
             logger.debug(f'Data fields not found in labeling config')
             return
-        fields_from_config = {field.split('[')[0] for field in fields_from_config}  # Repeater tag support
+
+        #TODO: DEV-2939 Add validation for fields addition in label config
+        '''fields_from_config = {field.split('[')[0] for field in fields_from_config}  # Repeater tag support
         fields_from_data = set(self.summary.common_data_columns)
         fields_from_data.discard(settings.DATA_UNDEFINED_NAME)
         if fields_from_data and not fields_from_config.issubset(fields_from_data):
             different_fields = list(fields_from_config.difference(fields_from_data))
             raise LabelStudioValidationErrorSentryIgnored(
                 f'These fields are not present in the data: {",".join(different_fields)}'
-            )
+            )'''
 
         if self.num_annotations == 0:
             logger.debug(
@@ -517,14 +520,18 @@ class Project(ProjectMixin, models.Model):
             diff_str = []
             for ann_tuple in different_annotations:
                 from_name, to_name, t = ann_tuple.split('|')
-                diff_str.append(
-                    f'{self.summary.created_annotations[ann_tuple]} '
-                    f'with from_name={from_name}, to_name={to_name}, type={t}'
+                if not check_control_in_config_by_regex(config_string, from_name) or \
+                not check_toname_in_config_by_regex(config_string, to_name) or \
+                t not in get_all_types(config_string):
+                    diff_str.append(
+                        f'{self.summary.created_annotations[ann_tuple]} '
+                        f'with from_name={from_name}, to_name={to_name}, type={t}'
+                    )
+            if len(diff_str) > 0:
+                diff_str = '\n'.join(diff_str)
+                raise LabelStudioValidationErrorSentryIgnored(
+                    f'Created annotations are incompatible with provided labeling schema, we found:\n{diff_str}'
                 )
-            diff_str = '\n'.join(diff_str)
-            raise LabelStudioValidationErrorSentryIgnored(
-                f'Created annotations are incompatible with provided labeling schema, we found:\n{diff_str}'
-            )
 
 
         # validate labels consistency
@@ -533,26 +540,30 @@ class Project(ProjectMixin, models.Model):
         for control_tag_from_data, labels_from_data in created_labels.items():
             # Check if labels created in annotations, and their control tag has been removed
             if labels_from_data and ((control_tag_from_data not in labels_from_config) and (
-                    control_tag_from_data not in dynamic_label_from_config)):
+                    control_tag_from_data not in dynamic_label_from_config)) and \
+                    not check_control_in_config_by_regex(config_string, control_tag_from_data):
                 raise LabelStudioValidationErrorSentryIgnored(
                     f'There are {sum(labels_from_data.values(), 0)} annotation(s) created with tag '
                     f'"{control_tag_from_data}", you can\'t remove it'
                 )
-            labels_from_config_by_tag = set(labels_from_config[control_tag_from_data])
+            labels_from_config_by_tag = set(labels_from_config[get_original_fromname_by_regex(config_string, control_tag_from_data)])
             parsed_config = parse_config(config_string)
             tag_types = [tag_info['type'] for _, tag_info in parsed_config.items()]
             if 'Taxonomy' in tag_types:
                 custom_tags = Label.objects.filter(links__project=self).values_list('value', flat=True)
                 flat_custom_tags = set([item for sublist in custom_tags for item in sublist])
                 labels_from_config_by_tag |= flat_custom_tags
+            # check if labels from is subset if config labels
             if not set(labels_from_data).issubset(set(labels_from_config_by_tag)):
                 different_labels = list(set(labels_from_data).difference(labels_from_config_by_tag))
                 diff_str = '\n'.join(f'{l} ({labels_from_data[l]} annotations)' for l in different_labels)
-                if (strict is True) and (control_tag_from_data not in dynamic_label_from_config):
+                if (strict is True) and ((control_tag_from_data not in dynamic_label_from_config) and
+                        (not check_control_in_config_by_regex(config_string, control_tag_from_data, filter=dynamic_label_from_config.keys()))):
+                    # raise error if labels not dynamic and not in regex rules
                     raise LabelStudioValidationErrorSentryIgnored(
                         f'These labels still exist in annotations:\n{diff_str}')
                 else:
-                    logger.warning(f'project_id={self.id} inconsistent labels in config and annotations: {diff_str}')
+                    logger.info(f'project_id={self.id} inconsistent labels in config and annotations: {diff_str}')
 
     def _label_config_has_changed(self):
         return self.label_config != self.__original_label_config
@@ -572,9 +583,9 @@ class Project(ProjectMixin, models.Model):
             if control_type in exclude_control_types:
                 continue
             control_weights[control_name] = {
-                'overall': 1.0,
+                'overall': self.control_weights.get(control_name, {}).get('overall') or 1.0,
                 'type': control_type,
-                'labels': {label: 1.0 for label in outputs[control_name].get('labels', [])},
+                'labels': {label: self.control_weights.get(control_name, {}).get('labels', {}).get(label) or 1.0 for label in outputs[control_name].get('labels', [])},
             }
         return control_weights
 
@@ -756,6 +767,13 @@ class Project(ProjectMixin, models.Model):
         return result
 
     def get_model_versions(self, with_counters=False):
+        """
+        Get model_versions from project predictions
+        :param with_counters: With count of predictions for each version
+        :return:
+        Dict or list
+        {model_version: count_predictions}, [model_versions]
+        """
         predictions = Prediction.objects.filter(task__project=self)
         # model_versions = set(predictions.values_list('model_version', flat=True).distinct())
         model_versions = predictions.values('model_version').annotate(count=Count('model_version'))
@@ -786,8 +804,12 @@ class Project(ProjectMixin, models.Model):
         total_annotations = Count("annotations", distinct=True, filter=Q(annotations__was_cancelled=False))
         cancelled_annotations = Count("annotations", distinct=True, filter=Q(annotations__was_cancelled=True))
         total_predictions = Count("predictions", distinct=True)
-        if isinstance(queryset, list):
+        # construct QuerySet in case of list of Tasks
+        if isinstance(queryset, list) and len(queryset) > 0 and isinstance(queryset[0], Task):
             queryset = Task.objects.filter(id__in=[task.id for task in queryset])
+        # construct QuerySet in case annotated queryset
+        if isinstance(queryset, TaskQuerySet) and queryset.exists() and isinstance(queryset[0], int):
+            queryset = Task.objects.filter(id__in=queryset)
 
         if not from_scratch:
             queryset = queryset.exclude(
@@ -969,8 +991,7 @@ class ProjectSummary(models.Model):
             return None
         if 'from_name' not in result or 'to_name' not in result:
             logger.error(
-                'Unexpected annotation.result format: "from_name" or "to_name" not found in %r',
-                result,
+                'Unexpected annotation.result format: "from_name" or "to_name" not found',
                 extra={'sentry_skip': True},
             )
             return None
