@@ -10,26 +10,26 @@ import json
 import getpass
 
 from colorama import init, Fore
+
 if sys.platform == 'win32':
     init(convert=True)
 
 # on windows there will be problems with sqlite and json1 support, so fix it
 from label_studio.core.utils.windows_sqlite_fix import windows_dll_fix
+
 windows_dll_fix()
 
 from django.core.management import call_command
-from django.db import IntegrityError
 from django.core.wsgi import get_wsgi_application
+from django.db import connections, DEFAULT_DB_ALIAS, IntegrityError
+from django.db.backends.signals import connection_created
 from django.db.migrations.executor import MigrationExecutor
-from django.db import connections, DEFAULT_DB_ALIAS
 
 from label_studio.core.argparser import parse_input_args
 from label_studio.core.utils.params import get_env
 
-
 logger = logging.getLogger(__name__)
 
-
 LS_PATH = str(pathlib.Path(__file__).parent.absolute())
 DEFAULT_USERNAME = 'default_user@localhost'
 
@@ -45,6 +45,13 @@ def _app_run(host, port):
     call_command('runserver', '--noreload', http_socket)
 
 
+def _set_sqlite_fix_pragma(sender, connection, **kwargs):
+    """Enable integrity constraint with sqlite."""
+    if connection.vendor == 'sqlite' and get_env('AZURE_MOUNT_FIX'):
+        cursor = connection.cursor()
+        cursor.execute('PRAGMA journal_mode=wal;')
+
+
 def is_database_synchronized(database):
     connection = connections[database]
     connection.prepare_database()
@@ -54,6 +61,7 @@ def is_database_synchronized(database):
 
 
 def _apply_database_migrations():
+    connection_created.connect(_set_sqlite_fix_pragma)
     if not is_database_synchronized(DEFAULT_DB_ALIAS):
         print('Initializing database..')
         call_command('migrate', '--no-color', verbosity=0)
@@ -295,7 +303,22 @@ def main():
 
     if input_args.command == 'calculate_stats_all_orgs':
         from tasks.functions import calculate_stats_all_orgs
-        calculate_stats_all_orgs(input_args.from_scratch)
+        calculate_stats_all_orgs(input_args.from_scratch, redis=True)
+        return
+
+    if input_args.command == 'export':
+        from tasks.functions import export_project
+
+        try:
+            filename = export_project(
+                input_args.project_id, input_args.export_format, input_args.export_path,
+                serializer_context=input_args.export_serializer_context
+            )
+        except Exception as e:
+            logger.exception(f'Failed to export project: {e}')
+        else:
+            logger.info(f'Project exported successfully: {filename}')
+
         return
 
     # print version
