@@ -10,6 +10,7 @@ from django.urls import reverse
 from django.core.files.images import get_image_dimensions
 
 from organizations.models import Organization
+from core.utils.contextlog import ContextLog
 from core.utils.common import load_func
 
 
@@ -62,6 +63,10 @@ def save_user(request, next_page, user_form):
     user.active_organization = org
     user.save(update_fields=['active_organization'])
 
+    request.advanced_json = {
+        'email': user.email, 'allow_newsletters': user.allow_newsletters,
+        'update-notifications': 1, 'new-user': 1
+    }
     redirect_url = next_page if next_page else reverse('projects:project-index')
     auth.login(request, user, backend='django.contrib.auth.backends.ModelBackend')
     return redirect(redirect_url)
